You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@servicemix.apache.org by gn...@apache.org on 2006/08/24 02:48:20 UTC

svn commit: r434274 - in /incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi: GenerateComponentDescriptorMojo.java GenerateSharedLibraryDescriptorMojo.java JbiComponentDescriptorWriter.java

Author: gnodet
Date: Wed Aug 23 17:48:19 2006
New Revision: 434274

URL: http://svn.apache.org/viewvc?rev=434274&view=rev
Log:
Add classloader delegation parameters for component and bootstrap.
Rename the parameter for SL for consistency and default them to "parent-first" as
specified in the JBI spec.

Modified:
    incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateComponentDescriptorMojo.java
    incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateSharedLibraryDescriptorMojo.java
    incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/JbiComponentDescriptorWriter.java

Modified: incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateComponentDescriptorMojo.java
URL: http://svn.apache.org/viewvc/incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateComponentDescriptorMojo.java?rev=434274&r1=434273&r2=434274&view=diff
==============================================================================
--- incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateComponentDescriptorMojo.java (original)
+++ incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateComponentDescriptorMojo.java Wed Aug 23 17:48:19 2006
@@ -106,6 +106,20 @@
 	 */
 	private String generatedDescriptorLocation;
 
+    /**
+     * The component class loader delegation
+     * 
+     * @parameter expression="self-first"
+     */
+    private String componentClassLoaderDelegation;
+
+    /**
+     * The bootstrap class loader delegation
+     * 
+     * @parameter expression="self-first"
+     */
+    private String bootstrapClassLoaderDelegation;
+
 	public void execute() throws MojoExecutionException, MojoFailureException {
 
 		getLog().debug(
@@ -223,6 +237,7 @@
 		JbiComponentDescriptorWriter writer = new JbiComponentDescriptorWriter(
 				encoding);
 		writer.write(descriptor, component, bootstrap, type, name, description,
+                componentClassLoaderDelegation, bootstrapClassLoaderDelegation,
 				uris);
 	}
 }

Modified: incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateSharedLibraryDescriptorMojo.java
URL: http://svn.apache.org/viewvc/incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateSharedLibraryDescriptorMojo.java?rev=434274&r1=434273&r2=434274&view=diff
==============================================================================
--- incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/JbiComponentDescriptorWriter.java (original)
+++ incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/JbiComponentDescriptorWriter.java Wed Aug 23 17:48:19 2006
@@ -35,7 +35,9 @@
 	}
 
 	public void write(File descriptor, String component, String bootstrap,
-			String type, String name, String description, List uris)
+			String type, String name, String description, 
+            String componentClassLoaderDelegation, String bootstrapClassLoaderDelegation, 
+            List uris)
 			throws JbiPluginException {
 		FileWriter w;
 		try {
@@ -52,6 +54,8 @@
 
 		writer.startElement("component");
 		writer.addAttribute("type", type);
+        writer.addAttribute("component-class-loader-delegation", componentClassLoaderDelegation);
+        writer.addAttribute("bootstrap-class-loader-delegation", componentClassLoaderDelegation);
 
 		writer.startElement("identification");
 		writer.startElement("name");
--- incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateSharedLibraryDescriptorMojo.java (original)
+++ incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/GenerateSharedLibraryDescriptorMojo.java Wed Aug 23 17:48:19 2006
@@ -73,11 +73,11 @@
 	private String version;
 
 	/**
 	 * The shared library class loader delegate
 	 * 
-	 * @parameter expression="self-first"
+	 * @parameter expression="parent-first"
 	 */
-	private String classLoaderDelegate;
+	private String classLoaderDelegation;
 
 	/**
 	 * Character encoding for the auto-generated application.xml file.
@@ -169,6 +169,6 @@
 		JbiSharedLibraryDescriptorWriter writer = new JbiSharedLibraryDescriptorWriter(
 				encoding);
 		writer.write(descriptor, name, description, version,
-				classLoaderDelegate, embeddedLibraries);
+				classLoaderDelegation, embeddedLibraries);
 	}
 }
@@ -73,11 +73,11 @@
 
 	/**
-	 * The shared library class loader delegate
+	 * The shared library class loader delegation
 	 * 

Modified: incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/JbiComponentDescriptorWriter.java
URL: http://svn.apache.org/viewvc/incubator/servicemix/trunk/tooling/jbi-maven-plugin/src/main/java/org/apache/servicemix/maven/plugin/jbi/JbiComponentDescriptorWriter.java?rev=434274&r1=434273&r2=434274&view=diff
==============================================================================